@@ -4,7 +4,7 @@ use strict;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw/extract_path_info reverse_path create_path_string/;
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 use Carp;
 
 # These are fields in the "arc" hash.
@@ -294,7 +294,7 @@ sub extract_path_info
         elsif (uc $curve_type eq 'Q') {
             my $expect_numbers = 4;
             if (@numbers % $expect_numbers != 0) {
-                croak "Wrong number of values for an L command " .
+                croak "Wrong number of values for an Q command " .
                     scalar @numbers . " in '$path'";
             }
             my $position = position_type ($curve_type);
@@ -313,7 +313,7 @@ sub extract_path_info
         elsif (uc $curve_type eq 'T') {
             my $expect_numbers = 2;
             if (@numbers % $expect_numbers != 0) {
-                croak "Wrong number of values for an L command " .
+                croak "Wrong number of values for an T command " .
                     scalar @numbers . " in '$path'";
             }
             my $position = position_type ($curve_type);
@@ -479,5 +479,4 @@ sub extract_path_info
 
 1;
 
-__END__
 
